Changelog
*********

1.0.0 (2017-12-19)
==================

- navigation initialized with kwargs (including variables
  coming from pytest variables too)

- add global timeout for all pages (default 10)

- base_page fixture no longer opens page by default. It's up to you
  visiting a page now


0.1.1 (2017-10-30)
==================

- support fallback page classes in action_performed


0.1.0 (2017-10-12)
==================

- Add update_page and action_performed methods on navigation.
- Wait for pages to load when visiting them.


0.0.1 (2017-06-13)
==================

* First release

